==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/layDialogs.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_layDialogs
#define HDR_layDialogs

#include "NewLayoutPropertiesDialog.h"
#include "NewLayerPropertiesDialog.h"
#include "NewCellPropertiesDialog.h"
#include "MoveOptionsDialog.h"
#include "DeleteCellModeDialog.h"
#include "ClearLayerModeDialog.h"
#include "OpenLayoutModeDialog.h"
#include "RenameCellDialog.h"
#include "BooleanOptionsDialog.h"
#include "SizingOptionsDialog.h"
#include "MergeOptionsDialog.h"
#include "AlignCellOptionsDialog.h"
#include "FlattenInstOptionsDialog.h"

#include "dbPoint.h"

namespace db
{
  class Layout;
}

namespace lay
{

class CellView;
class LayoutView;

/**
 *  @brief The new cell properties dialog
 */
class NewCellPropertiesDialog 
  : public QDialog,
    public Ui::NewCellPropertiesDialog
{
Q_OBJECT

public:
  NewCellPropertiesDialog (QWidget *parent);
  virtual ~NewCellPropertiesDialog ();

  bool exec (const db::Layout *layout, std::string &cell_name, double &size);

private:
  virtual void accept ();

  const db::Layout *mp_layout;
};

/**
 *  @brief The new layer properties dialog
 */
class NewLayerPropertiesDialog 
  : public QDialog,
    public Ui::NewLayerPropertiesDialog
{
Q_OBJECT

public:
  NewLayerPropertiesDialog (QWidget *parent);
  virtual ~NewLayerPropertiesDialog ();

  bool exec (const lay::CellView &cv, db::LayerProperties &src);

private:
  virtual void accept ();
  void get (db::LayerProperties &src);
};

/**
 *  @brief The move options dialog
 */
class MoveOptionsDialog 
  : public QDialog,
    public Ui::MoveOptionsDialog
{
Q_OBJECT

public:
  MoveOptionsDialog (QWidget *parent);
  virtual ~MoveOptionsDialog ();

  bool exec (db::DPoint &disp);

private:
  virtual void accept ();
};

/**
 *  @brief The rename cell options dialog
 */
class RenameCellDialog 
  : public QDialog,
    public Ui::RenameCellDialog
{
Q_OBJECT

public:
  RenameCellDialog (QWidget *parent);
  virtual ~RenameCellDialog ();

  bool exec (const db::Layout &layout, std::string &name);

private:
  virtual void accept ();

  const db::Layout *mp_layout;
};

/**
 *  @brief The delete cell options dialog
 */
class DeleteCellModeDialog 
  : public QDialog,
    public Ui::DeleteCellModeDialog
{
Q_OBJECT

public:
  DeleteCellModeDialog (QWidget *parent);
  virtual ~DeleteCellModeDialog ();

  /** 
   *  @brief Execute the dialog
   *
   *  The mode is either 0 (for shallow), 1 (for deep) and 2 (for complete)
   */
  bool exec (int &delete_mode);
};

/**
 *  @brief The delete cell options dialog
 */
class ClearLayerModeDialog 
  : public QDialog,
    public Ui::ClearLayerModeDialog
{
Q_OBJECT

public:
  ClearLayerModeDialog (QWidget *parent);
  virtual ~ClearLayerModeDialog ();

  /** 
   *  @brief Execute the dialog
   *
   *  The mode is either 0 (for locally), 1 (for hierarchically) and 2 (for all)
   */
  bool exec (int &clear_mode, const lay::CellView &cv);
};

/**
 *  @brief The open layout mode dialog
 */
class OpenLayoutModeDialog 
  : public QDialog,
    public Ui::OpenLayoutModeDialog
{
Q_OBJECT

public:
  OpenLayoutModeDialog (QWidget *parent);
  virtual ~OpenLayoutModeDialog ();

  /** 
   *  @brief Execute the dialog
   *
   *  The mode is either 0 (to replace current view), 1 (to create new view) and 2 (add to current view)
   */
  bool exec (int &open_mode);
};

/**
 *  @brief The new layout properties dialog
 */
class NewLayoutPropertiesDialog 
  : public QDialog,
    public Ui::NewLayoutPropertiesDialog
{
Q_OBJECT

public:
  NewLayoutPropertiesDialog (QWidget *parent);
  virtual ~NewLayoutPropertiesDialog ();

  bool exec (std::string &cell_name, double &dbu, double &window_size);

private:
  virtual void accept ();
};

/**
 *  @brief The boolean operation options
 */
class BooleanOptionsDialog 
  : public QDialog,
    public Ui::BooleanOptionsDialog
{
Q_OBJECT

public:
  BooleanOptionsDialog (QWidget *parent);
  virtual ~BooleanOptionsDialog ();

  bool exec (lay::LayoutView *view, int &cv_a, int &layer_a, int &cv_b, int &layer_b, int &cv_res, int &layer_res, int &mode, int &hier_mode, bool &min_coherence);

public slots:
  void cv_changed (int);

private:
  virtual void accept ();

  lay::LayoutView *mp_view;
};

/**
 *  @brief The sizing operation options
 */
class SizingOptionsDialog 
  : public QDialog,
    public Ui::SizingOptionsDialog
{
Q_OBJECT

public:
  SizingOptionsDialog (QWidget *parent);
  virtual ~SizingOptionsDialog ();

  bool exec (lay::LayoutView *view, int &cv, int &layer, int &cv_res, int &layer_res, double &dx, double &dy, unsigned int &size_mode, int &hier_mode, bool &min_coherence);

public slots:
  void cv_changed (int);

private:
  virtual void accept ();

  lay::LayoutView *mp_view;
};

/**
 *  @brief The merge operation options
 */
class MergeOptionsDialog 
  : public QDialog,
    public Ui::MergeOptionsDialog
{
Q_OBJECT

public:
  MergeOptionsDialog (QWidget *parent);
  virtual ~MergeOptionsDialog ();

  bool exec (lay::LayoutView *view, int &cv, int &layer, int &cv_res, int &layer_res, unsigned int &min_wc, int &hier_mode, bool &min_coherence);

public slots:
  void cv_changed (int);

private:
  virtual void accept ();

  lay::LayoutView *mp_view;
};

/**
 *  @brief The merge operation options
 */
class AlignCellOptionsDialog 
  : public QDialog,
    public Ui::AlignCellOptionsDialog
{
Q_OBJECT

public:
  AlignCellOptionsDialog (QWidget *parent);
  virtual ~AlignCellOptionsDialog ();

  bool exec (int &mode_x, int &mode_y, bool &visible_only);

public slots:
  void button_clicked ();
};

/**
 *  @brief Options dialog for the "flatten instances" function
 */
class FlattenInstOptionsDialog
  : public QDialog, 
    private Ui::FlattenInstOptionsDialog
{
public:
  FlattenInstOptionsDialog (QWidget *parent, bool enable_pruning = true);
  bool exec (int &levels, bool &prune); 
};

}

#endif

==> klayout-0.21.19.tar.gz: klayout-0.21.19/src/layDialogs.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


#ifndef HDR_layDialogs
#define HDR_layDialogs

#include "NewLayoutPropertiesDialog.h"
#include "NewLayerPropertiesDialog.h"
#include "NewCellPropertiesDialog.h"
#include "MoveOptionsDialog.h"
#include "DeleteCellModeDialog.h"
#include "ClearLayerModeDialog.h"
#include "OpenLayoutModeDialog.h"
#include "RenameCellDialog.h"
#include "BooleanOptionsDialog.h"
#include "SizingOptionsDialog.h"
#include "MergeOptionsDialog.h"
#include "AlignCellOptionsDialog.h"
#include "FlattenInstOptionsDialog.h"

#include "dbPoint.h"

namespace db
{
  class Layout;
}

namespace lay
{

class CellView;
class LayoutView;

/**
 *  @brief The new cell properties dialog
 */
class NewCellPropertiesDialog 
  : public QDialog,
    public Ui::NewCellPropertiesDialog
{
Q_OBJECT

public:
  NewCellPropertiesDialog (QWidget *parent);
  virtual ~NewCellPropertiesDialog ();

  bool exec (const db::Layout *layout, std::string &cell_name, double &size);

private:
  virtual void accept ();

  const db::Layout *mp_layout;
};

/**
 *  @brief The new layer properties dialog
 */
class NewLayerPropertiesDialog 
  : public QDialog,
    public Ui::NewLayerPropertiesDialog
{
Q_OBJECT

public:
  NewLayerPropertiesDialog (QWidget *parent);
  virtual ~NewLayerPropertiesDialog ();

  bool exec (const lay::CellView &cv, db::LayerProperties &src);
  bool exec (db::LayerProperties &src);

private:
  virtual void accept ();
  void get (db::LayerProperties &src);
};

/**
 *  @brief The move options dialog
 */
class MoveOptionsDialog 
  : public QDialog,
    public Ui::MoveOptionsDialog
{
Q_OBJECT

public:
  MoveOptionsDialog (QWidget *parent);
  virtual ~MoveOptionsDialog ();

  bool exec (db::DPoint &disp);

private:
  virtual void accept ();
};

/**
 *  @brief The rename cell options dialog
 */
class RenameCellDialog 
  : public QDialog,
    public Ui::RenameCellDialog
{
Q_OBJECT

public:
  RenameCellDialog (QWidget *parent);
  virtual ~RenameCellDialog ();

  bool exec (const db::Layout &layout, std::string &name);

private:
  virtual void accept ();

  const db::Layout *mp_layout;
};

/**
 *  @brief The delete cell options dialog
 */
class DeleteCellModeDialog 
  : public QDialog,
    public Ui::DeleteCellModeDialog
{
Q_OBJECT

public:
  DeleteCellModeDialog (QWidget *parent);
  virtual ~DeleteCellModeDialog ();

  /** 
   *  @brief Execute the dialog
   *
   *  The mode is either 0 (for shallow), 1 (for deep) and 2 (for complete)
   */
  bool exec (int &delete_mode);
};

/**
 *  @brief The delete cell options dialog
 */
class ClearLayerModeDialog 
  : public QDialog,
    public Ui::ClearLayerModeDialog
{
Q_OBJECT

public:
  ClearLayerModeDialog (QWidget *parent);
  virtual ~ClearLayerModeDialog ();

  /** 
   *  @brief Execute the dialog
   *
   *  The mode is either 0 (for locally), 1 (for hierarchically) and 2 (for all)
   */
  bool exec (int &clear_mode, const lay::CellView &cv);
};

/**
 *  @brief The open layout mode dialog
 */
class OpenLayoutModeDialog 
  : public QDialog,
    public Ui::OpenLayoutModeDialog
{
Q_OBJECT

public:
  OpenLayoutModeDialog (QWidget *parent);
  virtual ~OpenLayoutModeDialog ();

  /** 
   *  @brief Execute the dialog
   *
   *  The mode is either 0 (to replace current view), 1 (to create new view) and 2 (add to current view)
   */
  bool exec (int &open_mode);
};

/**
 *  @brief The new layout properties dialog
 */
class NewLayoutPropertiesDialog 
  : public QDialog,
    public Ui::NewLayoutPropertiesDialog
{
Q_OBJECT

public:
  NewLayoutPropertiesDialog (QWidget *parent);
  virtual ~NewLayoutPropertiesDialog ();

  bool exec (std::string &cell_name, double &dbu, double &window_size, bool &current_panel);

private:
  virtual void accept ();
};

/**
 *  @brief The boolean operation options
 */
class BooleanOptionsDialog 
  : public QDialog,
    public Ui::BooleanOptionsDialog
{
Q_OBJECT

public:
  BooleanOptionsDialog (QWidget *parent);
  virtual ~BooleanOptionsDialog ();

  bool exec (lay::LayoutView *view, int &cv_a, int &layer_a, int &cv_b, int &layer_b, int &cv_res, int &layer_res, int &mode, int &hier_mode, bool &min_coherence);

public slots:
  void cv_changed (int);

private:
  virtual void accept ();

  lay::LayoutView *mp_view;
};

/**
 *  @brief The sizing operation options
 */
class SizingOptionsDialog 
  : public QDialog,
    public Ui::SizingOptionsDialog
{
Q_OBJECT

public:
  SizingOptionsDialog (QWidget *parent);
  virtual ~SizingOptionsDialog ();

  bool exec (lay::LayoutView *view, int &cv, int &layer, int &cv_res, int &layer_res, double &dx, double &dy, unsigned int &size_mode, int &hier_mode, bool &min_coherence);

public slots:
  void cv_changed (int);

private:
  virtual void accept ();

  lay::LayoutView *mp_view;
};

/**
 *  @brief The merge operation options
 */
class MergeOptionsDialog 
  : public QDialog,
    public Ui::MergeOptionsDialog
{
Q_OBJECT

public:
  MergeOptionsDialog (QWidget *parent);
  virtual ~MergeOptionsDialog ();

  bool exec (lay::LayoutView *view, int &cv, int &layer, int &cv_res, int &layer_res, unsigned int &min_wc, int &hier_mode, bool &min_coherence);

public slots:
  void cv_changed (int);

private:
  virtual void accept ();

  lay::LayoutView *mp_view;
};

/**
 *  @brief The merge operation options
 */
class AlignCellOptionsDialog 
  : public QDialog,
    public Ui::AlignCellOptionsDialog
{
Q_OBJECT

public:
  AlignCellOptionsDialog (QWidget *parent);
  virtual ~AlignCellOptionsDialog ();

  bool exec (int &mode_x, int &mode_y, bool &visible_only);

public slots:
  void button_clicked ();
};

/**
 *  @brief Options dialog for the "flatten instances" function
 */
class FlattenInstOptionsDialog
  : public QDialog, 
    private Ui::FlattenInstOptionsDialog
{
public:
  FlattenInstOptionsDialog (QWidget *parent, bool enable_pruning = true);
  bool exec (int &levels, bool &prune); 
};

}

#endif
